@@ -1,12 +1,13 @@
-import common
+from tests import common
 import hglib
+from hglib.util import b
 
 class test_log(common.basetest):
     def test_basic(self):
         self.append('a', 'a')
-        rev0, node0 = self.client.commit('first', addremove=True)
+        rev0, node0 = self.client.commit(b('first'), addremove=True)
         self.append('a', 'a')
-        rev1, node1 = self.client.commit('second')
+        rev1, node1 = self.client.commit(b('second'))
 
         revs = self.client.log()
         revs.reverse()
@@ -14,11 +15,18 @@ class test_log(common.basetest):
         self.assertTrue(len(revs) == 2)
         self.assertEquals(revs[1].node, node1)
 
-        self.assertEquals(revs[0], self.client.log('0')[0])
-        self.assertEquals(self.client.log(), self.client.log(files=['a']))
+        self.assertEquals(revs[0], self.client.log(b('0'))[0])
+        self.assertEquals(self.client.log(), self.client.log(files=[b('a')]))
 
         self.assertEquals(self.client.log(), self.client.log(hidden=True))
 
+    def test_dash_in_filename(self):
+        self.append('-a', '-a')
+        self.client.commit(b('first'), addremove=True)
+        revs = self.client.log(files=[b('-a')])
+        self.assertTrue(len(revs) == 1)
+        self.assertEquals(revs[0].rev, b('0'))
+
     # def test_errors(self):
     #     self.assertRaisesRegexp(CommandError, 'abort: unknown revision',
     #                             self.client.log, 'foo')
